==> vips7.8_7.8.14.orig.tar.gz: vips-7.8.14/libsrcCC/VError.cc <==
// Code for error type

/*

    Copyright (C) 1991-2001 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

 */

#include <stdio.h>
#include <stdlib.h>

#include <iostream>

#include <vips/vips.h>
#include <vips/vipscpp.h>

#ifdef WITH_DMALLOC
#include <dmalloc.h>
#endif /*WITH_DMALLOC*/

void VError::perror() 
{ 
	std::cerr << note; 
	exit( 1 ); 
}

void VError::perror( const char *name ) 
{ 
	std::cerr << name << ": " << note; 
	exit( 1 ); 
}

// Add a new bit to the end of the error buffer
VError &VError::app( const int i )
{ 
	char buf[ 256 ];

	sprintf( buf, "%d", i );
	note += buf;

	return( *this );
}

VError &VError::app( const char *txt ) 
{ 
	note += txt; 

	return( *this );
}; 

// Error from VImage wrapper
void verror( const char *str )
{
	VError err;

	err.app( "VImage error: " ).app( str ).app( "\n" );

	throw( err );
}

// Error from VIPS function
void verror()
{
	VError err;

	err.app( "VIPS error: " ).app( im_errorstring() );
	im_clear_error_string();

	throw( err );
}

// Output accumulated string
std::ostream &operator<<( std::ostream &file, const VError &err )
{ 
	file << err.note;

	return file; 
}

==> vips_7.10.10.orig.tar.gz: vips-7.10.10/libsrcCC/VError.cc <==
// Code for error type

/*

    Copyright (C) 1991-2001 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif /*HAVE_CONFIG_H*/
#include <vips/intl.h>

#include <stdio.h>
#include <stdlib.h>

#include <iostream>

#include <vips/vips.h>
#include <vips/vipscpp.h>

#ifdef WITH_DMALLOC
#include <dmalloc.h>
#endif /*WITH_DMALLOC*/

void VError::perror() 
{ 
	std::cerr << note; 
	exit( 1 ); 
}

void VError::perror( const char *name ) 
{ 
	std::cerr << name << ": " << note; 
	exit( 1 ); 
}

// Add a new bit to the end of the error buffer
VError &VError::app( const int i )
{ 
	char buf[ 256 ];

	sprintf( buf, "%d", i );
	note += buf;

	return( *this );
}

VError &VError::app( const char *txt ) 
{ 
	note += txt; 

	return( *this );
}; 

// Error from VImage wrapper
void verror( const char *str )
{
	VError err;

	err.app( "VImage error: " ).app( str ).app( "\n" );

	throw( err );
}

// Error from VIPS function
void verror()
{
	VError err;

	err.app( "VIPS error: " ).app( im_error_buffer() );
	im_error_clear();

	throw( err );
}

// Output accumulated string
std::ostream &operator<<( std::ostream &file, const VError &err )
{ 
	file << err.note;

	return file; 
}
